@@ -3,8 +3,8 @@ use strict;
 use warnings;
 package Email::MIME;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.931'; # TRIAL
-use Email::Simple 2.104; # header_raw_*
+$Email::MIME::VERSION = '1.935'; # TRIAL
+use Email::Simple 2.206; # header_raw
 use parent qw(Email::Simple);
 
 use Carp ();
@@ -378,7 +378,7 @@ sub parts_multipart {
   my @parts;
   for my $bit (@bits) {
     $bit =~ s/\A[\n\r]+//smg;
-    $bit =~ s/(?<!\x0d)$self->{mycrlf}\Z//smg;
+    $bit =~ s/(?<!\x0d)$self->{mycrlf}\Z//sm;
     my $email = (ref $self)->new($bit);
     push @parts, $email;
   }
@@ -397,8 +397,8 @@ sub debug_structure {
   $level ||= 0;
   my $rv = " " x (5 * $level);
   $rv .= "+ " . ($self->content_type || '') . "\n";
-  my @parts = $self->parts;
-  if (@parts > 1) { $rv .= $_->debug_structure($level + 1) for @parts; }
+  my @parts = $self->subparts;
+  $rv .= $_->debug_structure($level + 1) for @parts;
   return $rv;
 }
 
@@ -805,7 +805,8 @@ sub _compose_content_type {
   my ($self, $ct_header) = @_;
   my $ct = join q{/}, @{$ct_header}{qw[type subtype]};
   for my $attr (sort keys %{ $ct_header->{attributes} }) {
-    $ct .= qq[; $attr="$ct_header->{attributes}{$attr}"];
+    next unless defined (my $value = $ct_header->{attributes}{$attr});
+    $ct .= qq[; $attr="$value"];
   }
   $self->header_raw_set('Content-Type' => $ct);
   $self->{ct} = $ct_header;
@@ -856,7 +857,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.931
+version 1.935
 
 =head1 SYNOPSIS
 
@@ -1232,7 +1233,7 @@ Simon Cozens <simon@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Vandiver Arthur Axel 'fREW' Schmidt Brian Cassidy David Steinbrunner Dotan Dimet Geraint Edwards Jesse Luehrs Kurt Anderson Matthew Horsfall (alh) memememomo Shawn Sorichetti Tomohiro Hosaka
+=for stopwords Alex Vandiver Arthur Axel 'fREW' Schmidt Brian Cassidy David Steinbrunner Dotan Dimet Geraint Edwards Jesse Luehrs Kurt Anderson Lance A. Brown Matthew Horsfall (alh) memememomo Shawn Sorichetti Tomohiro Hosaka
 
 =over 4
 
@@ -1270,6 +1271,10 @@ Kurt Anderson <kboth@drkurt.com>
 
 =item *
 
+Lance A. Brown <lance@bearcircle.net>
+
+=item *
+
 Matthew Horsfall (alh) <wolfsage@gmail.com>
 
 =item *
